@@ -52,7 +52,6 @@ GgvPostScriptView     *ggv_postscript_view_construct            (GgvPostScriptVi
 																 GtkGS *gs,
 																 gboolean zoom_fit);
 BonoboPropertyBag     *ggv_postscript_view_get_property_bag     (GgvPostScriptView *image_view);
-BonoboPropertyControl *ggv_postscript_view_get_property_control (GgvPostScriptView *image_view);
 void                  ggv_postscript_view_set_ui_container      (GgvPostScriptView *image_view,
 																 Bonobo_UIContainer ui_container);
 void                  ggv_postscript_view_unset_ui_container    (GgvPostScriptView *image_view);
@@ -64,19 +63,17 @@ void                  ggv_postscript_view_set_popup_ui_component(GgvPostScriptVi
 float ggv_postscript_view_get_zoom_factor (GgvPostScriptView *image_view);
 void  ggv_postscript_view_set_zoom_factor (GgvPostScriptView *image_view,
 										   float zoom_factor);
-gfloat ggv_postscript_view_zoom_to_fit     (GgvPostScriptView *image_view,
-											gboolean fit_width);
-void  ggv_postscript_view_set_zoom        (GgvPostScriptView *image_view,
-										   double zoomx,
-										   double zoomy);
+gfloat ggv_postscript_view_zoom_to_fit      (GgvPostScriptView *image_view,
+											 gboolean fit_width);
+void  ggv_postscript_view_set_zoom          (GgvPostScriptView *image_view,
+											 double zoomx,
+											 double zoomy);
 
 BonoboObject *ggv_postscript_view_add_interfaces (GgvPostScriptView *ps_view,
 												  BonoboObject *to_aggregate);
 
 void ggv_postscript_view_goto_page(GgvPostScriptView *ps_view, gint page);
 gint ggv_postscript_view_get_current_page(GgvPostScriptView *ps_view);
-gint ggv_postscript_view_get_page_count(GgvPostScriptView *ps_view);
-gchar **ggv_postscript_view_get_page_names(GgvPostScriptView *ps_view);
 
 /* Properties */
 void
