@@ -115,6 +115,12 @@ main (int argc, char *argv [])
 	bind_textdomain_codeset (PACKAGE, "UTF-8");                     
 	textdomain (PACKAGE);                                           
 
+	gnome_program_init ("ggv", VERSION,
+						LIBGNOMEUI_MODULE,
+						argc, argv,
+						GNOME_PARAM_APP_DATADIR, DATADIR,
+						NULL);
+
 	BONOBO_FACTORY_INIT ("ggv-postscript-viewer", VERSION, &argc, argv);
 
 	/*Init Stock Icons*/
