@@ -36,17 +36,13 @@ struct _GgvPrefsDialog
         GtkWidget *notebook;
 
         GtkWidget *gs, *alpha_params, *convert_pdf, *pdf2dsc, *unzip, *unbzip2, *print;   /* entries */
-        GtkWidget *size, *zoom, *orientation, *units, *auto_fit;      /* option menus */
+        GtkWidget *size, *zoom, *orientation, *units, *auto_fit;      /* combo boxes */
         GtkWidget *watch, *aa, *override_size, *respect_eof;
         GtkWidget *show_scroll_rect, *page_flip; /* checkbuttons */
         GtkWidget *override_orientation;
-        GtkWidget *sidebar, *mbar, *sbar, *toolbar, *tbstyle[GGV_TOOLBAR_STYLE_LAST], *savegeo,*auto_jump;/* checkbuttons */
+        GtkWidget *sidebar, *mbar, *sbar, *toolbar;
+        GtkWidget *savegeo, *auto_jump;/* checkbuttons */
         GtkWidget *right_panel;
-        GtkWidget **size_choice;               /* paper items */
-        GtkWidget **zoom_choice;               /* zoom items */
-        GtkWidget **orientation_choice;        /* orientation items */
-        GtkWidget **unit_choice;               /* unit items */
-        GtkWidget **auto_fit_choice;           /* auto-fit mode */
         GtkWidget *scroll_step;
 };
 
