@@ -332,7 +332,6 @@ verb_FileOpen(BonoboUIComponent *uic, gpointer data, const char *cname)
 					      NULL);
         gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(chooser), TRUE);
 	gtk_dialog_set_default_response(GTK_DIALOG(chooser), GTK_RESPONSE_OK);
-	gtk_window_set_default_size(GTK_WINDOW(chooser), 600, 400);
 
 #if 0
         /* this causes unexplained crashes! */
@@ -878,18 +877,24 @@ menu_position_under_widget (GtkMenu *menu, int *x, int *y,
 }
 
 static gboolean
-open_button_pressed_cb (GtkWidget *widget,
-                        GdkEventButton *event,
-                        gpointer *user_data)
+open_button_pressed_cb(GtkWidget *widget,
+                       GdkEventButton *event,
+                       gpointer *user_data)
 {
         GtkWidget *menu;
+        guint button = 0;
+        guint32 activate_time = GDK_CURRENT_TIME;
                                                                                                                              
         g_return_val_if_fail (GTK_IS_BUTTON (widget), FALSE); 
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE); 
 
 	menu = g_object_get_data (G_OBJECT (widget), "recent-menu");
+        if (event != NULL) {
+                button = event->button;
+                activate_time = event->time;
+        }
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, menu_position_under_widget, widget,
-			event->button, event->time);
+			button, activate_time);
  
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), FALSE);
         return TRUE;
