@@ -54,7 +54,8 @@ struct _GgvWindow
         GtkWidget *popup_menu;
         GtkWidget *view;
 
-        gboolean show_menus, show_sidebar, show_toolbar, show_statusbar;
+        gboolean show_menus, show_sidebar, show_toolbar;
+        gboolean show_statusbar;
 
         gboolean fullscreen;
         gint orig_x, orig_y, orig_width, orig_height;
@@ -67,15 +68,8 @@ struct _GgvWindow
         gchar *filename;
 	time_t mtime;
 	
-        gint current_page;
+        gint current_page, page_count;
 
-        /* these are values from ggv control: we keep a copy here that
-           we update on any change (mostly via the control's property
-           bag) in order to use CORBA to communicate with the control
-           as little as possible... */
-        CORBA_float doc_width, doc_height;
-        GNOME_GGV_Orientation doc_orient;
-        CORBA_long page, page_count;
 };
 
 struct _GgvWindowClass
@@ -87,11 +81,11 @@ GType     ggv_window_get_type           (void);
 GtkWidget *ggv_window_new               (void);
 void      ggv_window_close              (GgvWindow *win);
 gboolean  ggv_window_load               (GgvWindow *win, const gchar *filename);
-void      ggv_window_apply_prefs        (GgvWindow *win);
 void      ggv_window_sync_toolbar_style (GgvWindow *win);
 void      ggv_window_set_watch_file(GgvWindow *win, gboolean f);
 const GList *ggv_get_window_list(void);
 void      ggv_window_destroy_all(void);
+void      ggv_window_reload(GgvWindow *win);
 
 G_END_DECLS
 
