@@ -7,6 +7,14 @@
 
 #include <gtkgs.h>
 
+/*Define StockIds*/
+#define GGV_CLEAR_ALL		"ggv-clear-all"
+#define GGV_TOGGLE_ALL		"ggv-toggle-all"
+#define GGV_TOGGLE_EVEN		"ggv-toggle-even"
+#define GGV_TOGGLE_ODD		"ggv-toggle-odd"
+#define GGV_FIT_WIDTH		"ggv-fit-width"
+#define GGV_ZOOM		"ggv-zoom"
+
 extern GtkGSPaperSize ggv_paper_sizes[];
 extern const gchar *ggv_orientation_labels[];
 extern const gint ggv_max_orientation_labels;
@@ -52,4 +60,6 @@ void ggv_raise_and_focus_widget(GtkWidget *widget);
 
 void ggv_get_window_size(GtkWidget *widget, gint *width, gint *height);
 
+void ggv_init_stock_icons (void);
+
 #endif /* __GGV_UTILS_H__ */
