@@ -46,9 +46,13 @@ static GtkGSDefaults gtk_gs_defaults = {
 void 
 gtk_gs_defaults_set_scroll_step(gfloat step)
 {
-        gtk_gs_defaults.scroll_step = step;
-        gconf_client_set_float(gconf_client, "/apps/ggv/gtkgs/scrollstep",
-                               gtk_gs_defaults_get_scroll_step(), NULL);
+        if(fabs(gtk_gs_defaults.scroll_step - step) > 0.001) {
+                gtk_gs_defaults.scroll_step = step;
+                gconf_client_set_float(gconf_client,
+                                       "/apps/ggv/gtkgs/scrollstep",
+                                       gtk_gs_defaults_get_scroll_step(),
+                                       NULL);
+        }
 }
 
 gfloat
@@ -60,9 +64,11 @@ gtk_gs_defaults_get_scroll_step()
 void
 gtk_gs_defaults_set_size(gint iNewPageSize)
 {
-        gtk_gs_defaults.default_size = iNewPageSize;
-        gconf_client_set_int(gconf_client, "/apps/ggv/gtkgs/size",
-                             gtk_gs_defaults_get_size(), NULL);
+        if(gtk_gs_defaults.default_size != iNewPageSize) {
+                gtk_gs_defaults.default_size = iNewPageSize;
+                gconf_client_set_int(gconf_client, "/apps/ggv/gtkgs/size",
+                                     gtk_gs_defaults_get_size(), NULL);
+        }
 }
 
 gint
@@ -74,9 +80,13 @@ gtk_gs_defaults_get_size()
 void
 gtk_gs_defaults_set_override_size(gboolean bOverrSize)
 {
-        gtk_gs_defaults.override_size = bOverrSize;
-        gconf_client_set_bool(gconf_client, "/apps/ggv/gtkgs/override_size",
-                              gtk_gs_defaults_get_override_size(), NULL);
+        if(gtk_gs_defaults.override_size != bOverrSize) {
+                gtk_gs_defaults.override_size = bOverrSize;
+                gconf_client_set_bool(gconf_client,
+                                      "/apps/ggv/gtkgs/override_size",
+                                      gtk_gs_defaults_get_override_size(),
+                                      NULL);
+        }
 }
 
 gboolean
@@ -88,9 +98,13 @@ gtk_gs_defaults_get_override_size()
 void
 gtk_gs_defaults_set_override_orientation(gboolean bOverOrien)
 {
-        gtk_gs_defaults.override_orientation = bOverOrien;
-        gconf_client_set_bool(gconf_client, "/apps/ggv/gtkgs/override_orientation",
-                              gtk_gs_defaults_get_override_orientation(), NULL);
+        if(gtk_gs_defaults.override_orientation != bOverOrien) {
+                gtk_gs_defaults.override_orientation = bOverOrien;
+                gconf_client_set_bool(gconf_client,
+                                      "/apps/ggv/gtkgs/override_orientation",
+                                      gtk_gs_defaults_get_override_orientation(),
+                                      NULL);
+        }
 }
 
 gboolean
@@ -102,9 +116,12 @@ gtk_gs_defaults_get_override_orientation()
 void
 gtk_gs_defaults_set_antialiased(gint iNewAntialiased)
 {
-        gtk_gs_defaults.antialiased = iNewAntialiased;
-        gconf_client_set_bool(gconf_client, "/apps/ggv/gtkgs/antialiasing",
-                              gtk_gs_defaults_get_antialiased(), NULL);
+        if(gtk_gs_defaults.antialiased != iNewAntialiased) {
+                gtk_gs_defaults.antialiased = iNewAntialiased;
+                gconf_client_set_bool(gconf_client,
+                                      "/apps/ggv/gtkgs/antialiasing",
+                                      gtk_gs_defaults_get_antialiased(), NULL);
+        }
 }
 
 gboolean
@@ -118,9 +135,12 @@ gtk_gs_defaults_set_zoom_factor(gfloat fZoom)
 {
         fZoom = MIN(fZoom, 30.0);
         fZoom = MAX(0.05, fZoom);
-        gtk_gs_defaults.zoom_factor = fZoom;
-        gconf_client_set_float(gconf_client, "/apps/ggv/gtkgs/zoom",
-                               gtk_gs_defaults_get_zoom_factor(), NULL);
+        if(fabs(gtk_gs_defaults.zoom_factor - fZoom) > 0.001) {
+                gtk_gs_defaults.zoom_factor = fZoom;
+                gconf_client_set_float(gconf_client, "/apps/ggv/gtkgs/zoom",
+                                       gtk_gs_defaults_get_zoom_factor(),
+                                       NULL);
+        }
 }
 
 gfloat
@@ -137,9 +157,12 @@ gtk_gs_defaults_set_orientation(gint iNewOrientation) {
                   (iNewOrientation == GTK_GS_ORIENTATION_UPSIDEDOWN) ||
                   (iNewOrientation == GTK_GS_ORIENTATION_SEASCAPE)
                   );
-        gtk_gs_defaults.fallback_orientation = iNewOrientation;
-        gconf_client_set_int(gconf_client, "/apps/ggv/gtkgs/orientation",
-                             gtk_gs_defaults_get_orientation(), NULL);
+        if(gtk_gs_defaults.fallback_orientation != iNewOrientation) {
+                gtk_gs_defaults.fallback_orientation = iNewOrientation;
+                gconf_client_set_int(gconf_client,
+                                     "/apps/ggv/gtkgs/orientation",
+                                     gtk_gs_defaults_get_orientation(), NULL);
+        }
 }
 
 gint
@@ -151,9 +174,12 @@ gtk_gs_defaults_get_orientation()
 void
 gtk_gs_defaults_set_respect_eof(gboolean resp)
 {
-        gtk_gs_defaults.respect_eof = resp;
-        gconf_client_set_bool(gconf_client, "/apps/ggv/gtkgs/respect_eof",
-                              gtk_gs_defaults_get_respect_eof(), NULL);
+        if(gtk_gs_defaults.respect_eof != resp) {
+                gtk_gs_defaults.respect_eof = resp;
+                gconf_client_set_bool(gconf_client,
+                                      "/apps/ggv/gtkgs/respect_eof",
+                                      gtk_gs_defaults_get_respect_eof(), NULL);
+        }
 }
 
 gboolean
@@ -188,9 +214,13 @@ gtk_gs_defaults_get_show_scroll_rect()
 void
 gtk_gs_defaults_set_show_scroll_rect(gboolean f)
 {
-        gtk_gs_defaults.show_scroll_rect = f;
-        gconf_client_set_bool(gconf_client, "/apps/ggv/gtkgs/show_scroll_rect",
-                              gtk_gs_defaults_get_show_scroll_rect(), NULL);
+        if(gtk_gs_defaults.show_scroll_rect != f) {
+                gtk_gs_defaults.show_scroll_rect = f;
+                gconf_client_set_bool(gconf_client,
+                                      "/apps/ggv/gtkgs/show_scroll_rect",
+                                      gtk_gs_defaults_get_show_scroll_rect(),
+                                      NULL);
+        }
 }
 
 const gchar *
@@ -250,61 +280,90 @@ gtk_gs_defaults_get_unbzip2_cmd()
 void
 gtk_gs_defaults_set_interpreter_cmd(gchar *cmd)
 {
-        if(gtk_gs_defaults.interpreter_cmd)
-                g_free(gtk_gs_defaults.interpreter_cmd);
-        gtk_gs_defaults.interpreter_cmd = cmd;
-        gconf_client_set_string(gconf_client, "/apps/ggv/gtkgs/interpreter",
-                                gtk_gs_defaults_get_interpreter_cmd(), NULL);
+        if((NULL == gtk_gs_defaults.interpreter_cmd) ||
+           strcmp(gtk_gs_defaults.interpreter_cmd, cmd)) {
+                if(gtk_gs_defaults.interpreter_cmd)
+                        g_free(gtk_gs_defaults.interpreter_cmd);
+                gtk_gs_defaults.interpreter_cmd = cmd;
+                gconf_client_set_string(gconf_client,
+                                        "/apps/ggv/gtkgs/interpreter",
+                                        gtk_gs_defaults_get_interpreter_cmd(),
+                                        NULL);
+        }
 }
 
 void
 gtk_gs_defaults_set_alpha_parameters(gchar *par)
 {
-        if(gtk_gs_defaults.alpha_params)
-                g_free(gtk_gs_defaults.alpha_params);
-        gtk_gs_defaults.alpha_params = par;
-        gconf_client_set_string(gconf_client, "/apps/ggv/gtkgs/alphaparams",
-                                gtk_gs_defaults_get_alpha_parameters(), NULL);
+        if((NULL == gtk_gs_defaults.alpha_params) ||
+           strcmp(gtk_gs_defaults.alpha_params, par)) {
+                if(gtk_gs_defaults.alpha_params)
+                        g_free(gtk_gs_defaults.alpha_params);
+                gtk_gs_defaults.alpha_params = par;
+                gconf_client_set_string(gconf_client,
+                                        "/apps/ggv/gtkgs/alphaparams",
+                                        gtk_gs_defaults_get_alpha_parameters(),
+                                        NULL);
+        }
 }
 
 void
 gtk_gs_defaults_set_convert_pdf_cmd(gchar *cmd)
 {
-        if(gtk_gs_defaults.convert_pdf_cmd)
-                g_free(gtk_gs_defaults.convert_pdf_cmd);
-        gtk_gs_defaults.convert_pdf_cmd = cmd;
-        gconf_client_set_string(gconf_client, "/apps/ggv/gtkgs/convertpdf",
-                                gtk_gs_defaults_get_convert_pdf_cmd(), NULL);
+        if((NULL == gtk_gs_defaults.convert_pdf_cmd) ||
+           strcmp(gtk_gs_defaults.convert_pdf_cmd, cmd)) {
+                if(gtk_gs_defaults.convert_pdf_cmd)
+                        g_free(gtk_gs_defaults.convert_pdf_cmd);
+                gtk_gs_defaults.convert_pdf_cmd = cmd;
+                gconf_client_set_string(gconf_client,
+                                        "/apps/ggv/gtkgs/convertpdf",
+                                        gtk_gs_defaults_get_convert_pdf_cmd(),
+                                        NULL);
+        }
 }
 
 void
 gtk_gs_defaults_set_dsc_cmd(gchar *cmd)
 {
-        if(gtk_gs_defaults.dsc_cmd)
-                g_free(gtk_gs_defaults.dsc_cmd);
-        gtk_gs_defaults.dsc_cmd = cmd;
-        gconf_client_set_string(gconf_client, "/apps/ggv/gtkgs/pdf2dsc",
-                                gtk_gs_defaults_get_dsc_cmd(), NULL);
+        if((NULL == gtk_gs_defaults.dsc_cmd) ||
+           strcmp(gtk_gs_defaults.dsc_cmd, cmd)) {
+                if(gtk_gs_defaults.dsc_cmd)
+                        g_free(gtk_gs_defaults.dsc_cmd);
+                gtk_gs_defaults.dsc_cmd = cmd;
+                gconf_client_set_string(gconf_client,
+                                        "/apps/ggv/gtkgs/pdf2dsc",
+                                        gtk_gs_defaults_get_dsc_cmd(), NULL);
+        }
 }
 
 void
 gtk_gs_defaults_set_ungzip_cmd(gchar *cmd)
 {
-        if(gtk_gs_defaults.ungzip_cmd)
-                g_free(gtk_gs_defaults.ungzip_cmd);
-        gtk_gs_defaults.ungzip_cmd = cmd;
-        gconf_client_set_string(gconf_client, "/apps/ggv/gtkgs/ungzip",
-                                gtk_gs_defaults_get_ungzip_cmd(), NULL);
+        if((NULL == gtk_gs_defaults.ungzip_cmd) ||
+           strcmp(gtk_gs_defaults.ungzip_cmd, cmd)) {
+                if(gtk_gs_defaults.ungzip_cmd)
+                        g_free(gtk_gs_defaults.ungzip_cmd);
+                gtk_gs_defaults.ungzip_cmd = cmd;
+                gconf_client_set_string(gconf_client,
+                                        "/apps/ggv/gtkgs/ungzip",
+                                        gtk_gs_defaults_get_ungzip_cmd(),
+                                        NULL);
+        }
 }
 
 void
 gtk_gs_defaults_set_unbzip2_cmd(gchar *cmd)
 {
-        if(gtk_gs_defaults.unbzip2_cmd)
-                g_free(gtk_gs_defaults.unbzip2_cmd);
-        gtk_gs_defaults.unbzip2_cmd = cmd;
-        gconf_client_set_string(gconf_client, "/apps/ggv/gtkgs/unbzip2",
-                                gtk_gs_defaults_get_unbzip2_cmd(), NULL);
+        if((NULL == gtk_gs_defaults.unbzip2_cmd) ||
+           strcmp(gtk_gs_defaults.unbzip2_cmd, cmd)) {
+                if(gtk_gs_defaults.unbzip2_cmd)
+                        g_free(gtk_gs_defaults.unbzip2_cmd);
+                gtk_gs_defaults.unbzip2_cmd = cmd;
+                gconf_client_set_string(gconf_client,
+                                        "/apps/ggv/gtkgs/unbzip2",
+                                        gtk_gs_defaults_get_unbzip2_cmd(),
+                                        NULL);
+        }
 }
 
 GtkGSZoomMode
@@ -316,9 +375,11 @@ gtk_gs_defaults_get_zoom_mode()
 void
 gtk_gs_defaults_set_zoom_mode(GtkGSZoomMode zoom_mode)
 {
-        gtk_gs_defaults.zoom_mode = zoom_mode;
-        gconf_client_set_int(gconf_client, "/apps/ggv/gtkgs/zoommode",
-                             gtk_gs_defaults_get_zoom_mode(), NULL);
+        if(gtk_gs_defaults.zoom_mode != zoom_mode) {
+                gtk_gs_defaults.zoom_mode = zoom_mode;
+                gconf_client_set_int(gconf_client, "/apps/ggv/gtkgs/zoommode",
+                                     gtk_gs_defaults_get_zoom_mode(), NULL);
+        }
 }
 
 void
