@@ -112,8 +112,10 @@ The DONE message indicates that ghostscript has finished processing.
 #include <stdlib.h>
 #include <signal.h>
 #include <gtk/gtk.h>
+#include <gtk/gtkobject.h>
 #include <gdk/gdkprivate.h>
 #include <gdk/gdkx.h>
+#include <gdk/gdk.h>
 #ifdef  HAVE_XINERAMA
 #  include <gdk/gdkx.h>
 #  include <X11/extensions/Xinerama.h>
@@ -454,7 +456,7 @@ gtk_gs_cleanup (GtkGS *gs)
                 g_free(gs->gs_filename_unc);
                 gs->gs_filename_unc = NULL;
         }
-        if(gs->pstarget && !gdk_window_is_visible(gs->pstarget))
+        if(gs->pstarget && gdk_window_is_visible(gs->pstarget))
                 gdk_window_hide(gs->pstarget);
         gs->current_page = -1;
         gs->loaded = FALSE;
@@ -1715,7 +1717,8 @@ gtk_gs_load (GtkGS *gs, const gchar *fname)
         gtk_gs_cleanup(gs);
 
 	if (fname == NULL) {
-                if(gdk_window_is_visible(gs->pstarget))
+                if(gs->pstarget != NULL &&
+                   gdk_window_is_visible(gs->pstarget))
                         gdk_window_hide(gs->pstarget);
                 gs->gs_status = "";
 		return FALSE;
