@@ -40,7 +40,7 @@ typedef enum
         GTK_GS_ORIENTATION_PORTRAIT = 0,
         GTK_GS_ORIENTATION_SEASCAPE = 3,
         GTK_GS_ORIENTATION_UPSIDEDOWN = 2,
-        GTK_GS_ORIENTATION_LANDSCAPE = 1,
+        GTK_GS_ORIENTATION_LANDSCAPE = 1
 } GtkGSOrientation;
 
 typedef enum
