@@ -400,16 +400,6 @@ end_element_handler (GMarkupParseContext *context,
 				info->current_item = NULL;
 				break;
 			}
-			uri = gnome_vfs_uri_new(info->current_item->uri);
-			if(uri) {
-				if(!gnome_vfs_uri_exists(uri)) {
-					gnome_vfs_uri_unref(uri);
-					egg_recent_item_unref(info->current_item);
-					info->current_item = NULL;
-					break;
-				}
-				gnome_vfs_uri_unref(uri);
-			}
 			info->items = g_list_append (info->items,
 						     info->current_item);
 			break;
@@ -540,6 +530,7 @@ egg_recent_model_filter (EggRecentModel *model,
 		gboolean pass_mime_test = FALSE;
 		gboolean pass_group_test = FALSE;
 		gboolean pass_scheme_test = FALSE;
+
 		item = (EggRecentItem *)list->data;
 		list = list->next;
 
@@ -563,9 +554,9 @@ egg_recent_model_filter (EggRecentModel *model,
 			if (egg_recent_model_group_match
 					(item, model->priv->group_filter_values))
 				pass_group_test = TRUE;
-		} else if (egg_recent_item_get_private (item)) {
+		} else if (egg_recent_item_get_private (item))
 			pass_group_test = FALSE;
-		} else
+		else
 			pass_group_test = TRUE;
 
 		/* filter by URI scheme */
@@ -584,7 +575,7 @@ egg_recent_model_filter (EggRecentModel *model,
 			pass_scheme_test = TRUE;
 
 		if (pass_mime_test && pass_group_test && pass_scheme_test)
-			newlist = g_list_prepend (newlist, item);
+			newlist = g_list_prepend(newlist, item);
 
 		g_free (uri);
 	}
@@ -594,7 +585,6 @@ egg_recent_model_filter (EggRecentModel *model,
 		g_list_free (list);
 	}
 
-	
 	return newlist;
 }
 
